<h1 align="center">🦙 LlamaChat</h1>
<p align="center">
    <img src="assets/banner.png">
  <i>Streamlit UI build for <a href="https://gpt-index.readthedocs.io/">LlamaIndex</a> for Pycon India 23</i>
</p>

Try it out with 
```
pip install llamachat
llamachat <path-to-index-storage>
```
